@@ -14,8 +14,7 @@ if RECOMMENDS_TASK_RUN:
 
         # I know this is weird, but it's faster (tested on CPyhton 2.6.5)
         def _precompute(provider_instance):
-            result = provider_instance.precompute()
-            results.append(result)
+            results.append(provider_instance.precompute())
 
         with filelock('recommends_precompute.lock'):
             [_precompute(provider_instance)
